//
//  ASTransferStatsFormatter.h
//

/*
 *  Licensed Materials - Property of IBM
 *  IBM Product Name: 5725S57
 *  Copyright IBM Corp. 2011, 2015
 *  US Government Users Restricted Rights - Use, 
 *  duplication or disclosure restricted by GSA 
 *  ADP Schedule Contract with IBM Corp.
 *
 *  Copyright 2011 Aspera. All rights reserved.
 */


#ifndef __MOBILE_SDK_AS_TRANSFER_STATS_FORMATTER__
#define __MOBILE_SDK_AS_TRANSFER_STATS_FORMATTER__

#import <Foundation/Foundation.h>

/**
   \brief (Internal)

   Provides transfer statistics formatting for ASTransferStats. All
   formatting methods are class methods, there is no need to
   instantiate this class.
*/
@interface ASTransferStatsFormatter : NSObject {
}

/**
    @name Time Formatting Methods
    @{
 */

/**
   Takes a given number of seconds as a double and
   returns a string of the form:
      - "0.XXs" for a durations under 1sec
      - "Xs" for a durations under 1min
      - "Xm Ys" for a durations over 1min
      - "Xh Ym" for durations over 1hr
      - "Xd Yh" for durations over 1day
*/
+ (NSString *)prettyTimeFromDouble:(double)seconds;
+ (NSString *)fractionalSecondsFromDouble:(double)seconds;
+ (NSString *)secondsFromDouble:(double)seconds;
+ (NSString *)minutesAndSecondsFromDouble:(double)d_seconds;
+ (NSString *)hoursAndMinutesFromDouble:(double)d_seconds;
+ (NSString *)daysAndHoursFromDouble:(double)d_seconds;

/**
   @}
*/



/**
   @name Space Formatting Methods
   @{
 */

/**
   Takes a number of bits as an unsigned long long, and returns
   the largest metric unit of bits contained within, to two decimal
   points accuracy and labeled with the given label.
   Note that in this context the metric units 'kilo', 'mega',
   'giga' and 'tera' measure 10^3, 10^6, 10^9 and 10^12, respectively.

   Examples:
     metricBitsFromULL:1059 label:@"b"  -> "1.05 Kb"
     metricBitsFromULL:691100 label:@"b/s" -> "6.91 Mb/s"
 */
+ (NSString *)metricBitsFromULL:(unsigned long long)bits
                          label:(NSString *)label;

/**
   Takes a number of bytes as an unsigned long long, and returns
   the largest metric unit of bytes contained within, to two decimal
   points accuracy and labeled with the given label.
   Note that in this context the metric units 'kilo', 'mega',
   'giga' and 'tera' measure 1024, 1024^2, 1024^3 and 1024^4, respectively.

   Examples:
     metricBitsFromULL:1024 label:@"B"  -> "1.00 KB"
     metricBitsFromULL:1048576 label:@"B/s" -> "1.00 MB/s"
*/
+ (NSString *)metricBytesFromULL:(unsigned long long)bytes
                           label:(NSString *)label;

/**
   Takes a quantity and definitions of size for kilo, mega, giga
   and tera and returns the largest units contained in that quantity,
   to two decimal places and labeled with the given label.
*/
+ (NSString *)largestMetricUnitFromULL:(unsigned long long)quantity
                                 label:(NSString *)label
                                  kilo:(unsigned long long)kilo
                                  mega:(unsigned long long)mega
                                  giga:(unsigned long long)giga
                                  tera:(unsigned long long)tera;

+ (NSString *)quantityFromULL:(unsigned long long)units
                        label:(NSString *)label;

+ (NSString *)kiloQuantityFromULL:(unsigned long long)units
                            label:(NSString *)label
                             kilo:(unsigned long long)kilo;

+ (NSString *)megaQuantityFromULL:(unsigned long long)units
                            label:(NSString *)label
                             mega:(unsigned long long)mega;

+ (NSString *)gigaQuantityFromULL:(unsigned long long)units
                            label:(NSString *)label
                             giga:(unsigned long long)giga;

+ (NSString *)teraQuantityFromULL:(unsigned long long)units
                            label:(NSString *)label
                             tera:(unsigned long long)tera;


/**
    @}
*/

@end


#endif // __MOBILE_SDK_AS_TRANSFER_STATS_FORMATTER__
