/*
 *  Licensed Materials - Property of IBM
 *  IBM Product Name: 5725S57
 *  Copyright IBM Corp. 2011, 2015
 *  US Government Users Restricted Rights - Use, 
 *  duplication or disclosure restricted by GSA 
 *  ADP Schedule Contract with IBM Corp.
 */

#import "ASFaspConstants.h"

/**
   Encapsulates many of the parameters needed to create a transfer session
*/
@interface ASFaspSessionParameters: NSObject

/**
   Create a set of transfer parameters describing an upload with the given host and user
 */
+ (nonnull instancetype)uploadSessionWithHost:(nonnull NSString *)hst user:(nonnull NSString *)usr;

/**
   Create a set of transfer parameters describing a download with the given host and user
 */
+ (nonnull instancetype)downloadSessionWithHost:(nonnull NSString *)hst user:(nonnull NSString *)usr;
+ (nonnull instancetype)sessionWithDirection:(ASFaspDirection)dir host:(nonnull NSString *)hst user:(nonnull NSString *)usr;
- (nonnull instancetype)initWithDirection:(ASFaspDirection)dir host:(nonnull NSString *)hst user:(nonnull NSString *)usr;
- (nonnull NSString *)parametersDescription;

// Transfer operation
/**
   The transfer direction, one of ASFaspDirectionUpload or ASFaspDirectionDownload
 */
@property (nonatomic) ASFaspDirection direction;

// Remote host
/** Remote host to transfer to or from, e.g. example.com or 192.168.0.1 */
@property (nonatomic, strong, nonnull) NSString *host;
/** SSH port to use for the transfer. Defaults to 22. */
@property (nonatomic) int sshPort;
/** UDP port to use for the transfer. Defaults to 33001 */
@property (nonatomic) int udpPort;
/** Destination on the remote server to/from which to transfer */
@property (nonatomic, strong, nonnull) NSString *destinationPath;

// Auth
/** Username to use for the transfer */
@property (nonatomic, strong, nonnull) NSString *user;
/** Password to use for authentication. Either a password or a private key is necessary */
@property (nonatomic, strong, nonnull) NSString *password;
/** Full path to the private key to use for authentication. Either a private key or a password is necessary */
@property (nonatomic, strong, nonnull) NSString *privateKeyFilename;
/** Passphrase to use in case the private key is passphrase-protected */
@property (nonatomic, strong, nonnull) NSString *privateKeyPassphrase;
/** Token to use for transfer authentication. Tokens are optional and are used in conjunction with username-and-password or username-and-privatekey authentication */
@property (nonatomic, strong, nonnull) NSString *token;

// EAR
/** Controls whether encryption at rest (EAR) is enabled or disabled. Defaults to false */
@property (nonatomic) BOOL earEnabled;
/** The passphrase to use when EAR is enabled */
@property (nonatomic, strong, nonnull) NSString *earPassphrase;

// Over the wire
@property (nonatomic) ASRateAlgorithm rateControlAlgorithm;
/** Controls the encryption of data over the wire (as opposed to encryption at rest). One of ASCipherNone, ASCipherAES192 or ASCipherAES256. The default is ASCipherAES128 */
@property (nonatomic) ASCipher encryptionCipher;
@property (nonatomic) int datagramSize;
@property (nonatomic) BOOL usePMTUDiscover;

// Rate parameters
/** The target rate to use for the transfer in bits per second. The ultimate value determining the session's target rate is the targetRate attribute of an ASFaspSession or ASPeristentFaspSession instance; note that this value may be modified by the server or by calling -[ASAbstractFaspSession setTargetRate:] on the session */
@property (nonatomic) unsigned long long initialTargetRate;
@property (nonatomic) unsigned long long minTargetRate;
@property (nonatomic) unsigned long long bandwidthCap;

/** The transfer rate policy, one of ASRatePolicyFixed, ASRatePolicyFair or ASRacePolicyTrickle. The default is ASRatePolicyFair */
@property (nonatomic) ASRatePolicy ratePolicy;
// Other
/** A string cookie to pass along to the FASP session */
@property (nonatomic, strong, nonnull) NSString *cookie;
/** A JSON formatted string to pass along to the FASP session as tags */
@property (nonatomic, strong, nonnull) NSString *tags;
/** The session create policy. Valid values are ASCreatePolicyPreserveTime, ASCreatePolicyBackup, ASCreatePolicySkipExisting, ASCreatePolicyDirPath. The default is ASCreatePolicyDirPath */
@property (nonatomic) ASCreatePolicy createPolicy;
/** File resume policy, one of ASResumePolicyNone, ASResumePolicyAttrs, AASResumePolicyFullCsum, ASResumePolicySparseCsum. */
@property (nonatomic) ASResumePolicy resumePolicy;
/** File overwrite policy, one of ASOverwritePolicyDiff, ASOverwritePolicyOlder, ASOverwritePolicyNever or ASOverwriteolicyAlways.*/
@property (nonatomic) ASOverwritePolicy overwritePolicy;
/** Whether or not session transfer size is precalculated on the server before the transfer. One of ASPrecalcYes or ASPrecalcNo. The default is ASPrecalcYes */
@property (nonatomic) ASFaspPrecalc precalc;

@end


